==> jc-1.4.0.tar.gz: ppg/parse/Constant.h <==
// public class ppg.parse.Constant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fa8682f708c87312 ppg_parse_Constant

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_parse_Constant_H_
#define _JC_ppg_parse_Constant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_ppg_parse_Constant$sub_refs	_jc_ppg_parse_Constant$sub_refs;
typedef struct _jc_ppg_parse_Constant$sub_nonrefs	_jc_ppg_parse_Constant$sub_nonrefs;
typedef struct _jc_ppg_parse_Constant$refs	_jc_ppg_parse_Constant$refs;
typedef struct _jc_ppg_parse_Constant$nonrefs	_jc_ppg_parse_Constant$nonrefs;
typedef struct _jc_ppg_parse_Constant$object	_jc_ppg_parse_Constant$object;

typedef struct _jc_ppg_parse_Constant$fields_struct	_jc_ppg_parse_Constant$fields_struct;
typedef const struct _jc_ppg_parse_Constant$vmethods	_jc_ppg_parse_Constant$vmethods;
typedef const struct _jc_ppg_parse_Constant$vtable	_jc_ppg_parse_Constant$vtable;
typedef const struct _jc_ppg_parse_Constant$vtype	_jc_ppg_parse_Constant$vtype;

// Class fields structure
struct _jc_ppg_parse_Constant$fields_struct {
	jint	ACTION;
	jint	BAR;
	jint	CODE;
	jint	CODE__5fSTR;
	jint	COLON;
	jint	COLON__5fCOLON__5fEQUALS;
	jint	COMMA;
	jint	DOT;
	jint	DROP;
	jint	EOF;
	jint	EXTEND;
	jint	EXTENDS;
	jint	ID;
	jint	IMPLEMENTS;
	jint	IMPORT;
	jint	INCLUDE;
	jint	INIT;
	jint	LBRACE;
	jint	LBRACK;
	jint	LEFT;
	jint	NON;
	jint	NONASSOC;
	jint	NONTERMINAL;
	jint	OVERRIDE;
	jint	PACKAGE;
	jint	PARSER;
	jint	PERCENT__5fPREC;
	jint	PRECEDENCE;
	jint	RBRACE;
	jint	RBRACK;
	jint	RIGHT;
	jint	SCAN;
	jint	SEMI;
	jint	STAR;
	jint	START;
	jint	STRING__5fCONST;
	jint	TERMINAL;
	jint	TO;
	jint	TRANSFER;
	jint	WITH;
	jint	error;
};
extern _jc_ppg_parse_Constant$fields_struct _jc_ppg_parse_Constant$class_fields;

// Constructors
extern void _jc_ppg_parse_Constant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_parse_Constant$object *);

// Virtual methods structure
struct _jc_ppg_parse_Constant$vmethods {
};

// Vtable
struct _jc_ppg_parse_Constant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_parse_Constant$vmethods	ppg_parse_Constant;
};

// Vtype
struct _jc_ppg_parse_Constant$vtype {
	_jc_type			type;
	_jc_ppg_parse_Constant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_parse_Constant$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_parse_Constant$refs {
    _jc_ppg_parse_Constant$sub_refs	ppg_parse_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_parse_Constant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_parse_Constant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_parse_Constant$sub_nonrefs	ppg_parse_Constant;
};

// Object instance structure
struct _jc_ppg_parse_Constant$object {
	_jc_ppg_parse_Constant$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_parse_Constant$vtype	*vtype;
	_jc_ppg_parse_Constant$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_parse_Constant$vtype _jc_ppg_parse_Constant$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_parse_Constant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_parse_Constant$class_object;

#endif	/* _JC_ppg_parse_Constant_H_ */

==> jc-1.4.6.tar.gz: ppg/parse/Constant.h <==
// public class ppg.parse.Constant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fa8682f708c87312 ppg_parse_Constant

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_parse_Constant_H_
#define _JC_ppg_parse_Constant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_ppg_parse_Constant$sub_refs	_jc_ppg_parse_Constant$sub_refs;
typedef struct _jc_ppg_parse_Constant$sub_nonrefs	_jc_ppg_parse_Constant$sub_nonrefs;
typedef struct _jc_ppg_parse_Constant$refs	_jc_ppg_parse_Constant$refs;
typedef struct _jc_ppg_parse_Constant$nonrefs	_jc_ppg_parse_Constant$nonrefs;
typedef struct _jc_ppg_parse_Constant$object	_jc_ppg_parse_Constant$object;

typedef struct _jc_ppg_parse_Constant$fields_struct	_jc_ppg_parse_Constant$fields_struct;
typedef const struct _jc_ppg_parse_Constant$vmethods	_jc_ppg_parse_Constant$vmethods;
typedef const struct _jc_ppg_parse_Constant$vtable	_jc_ppg_parse_Constant$vtable;
typedef const struct _jc_ppg_parse_Constant$vtype	_jc_ppg_parse_Constant$vtype;

// Class fields structure
struct _jc_ppg_parse_Constant$fields_struct {
	jint	ACTION;
	jint	BAR;
	jint	CODE;
	jint	CODE__5fSTR;
	jint	COLON;
	jint	COLON__5fCOLON__5fEQUALS;
	jint	COMMA;
	jint	DOT;
	jint	DROP;
	jint	EOF;
	jint	EXTEND;
	jint	EXTENDS;
	jint	ID;
	jint	IMPLEMENTS;
	jint	IMPORT;
	jint	INCLUDE;
	jint	INIT;
	jint	LBRACE;
	jint	LBRACK;
	jint	LEFT;
	jint	NON;
	jint	NONASSOC;
	jint	NONTERMINAL;
	jint	OVERRIDE;
	jint	PACKAGE;
	jint	PARSER;
	jint	PERCENT__5fPREC;
	jint	PRECEDENCE;
	jint	RBRACE;
	jint	RBRACK;
	jint	RIGHT;
	jint	SCAN;
	jint	SEMI;
	jint	STAR;
	jint	START;
	jint	STRING__5fCONST;
	jint	TERMINAL;
	jint	TO;
	jint	TRANSFER;
	jint	WITH;
	jint	error;
};
extern _jc_ppg_parse_Constant$fields_struct _jc_ppg_parse_Constant$class_fields;

// Constructors
extern void _jc_ppg_parse_Constant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_parse_Constant$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_ppg_parse_Constant$vmethods {
};

// Vtable
struct _jc_ppg_parse_Constant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_parse_Constant$vmethods	ppg_parse_Constant;
};

// Vtype
struct _jc_ppg_parse_Constant$vtype {
	_jc_type			type;
	_jc_ppg_parse_Constant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_parse_Constant$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_parse_Constant$refs {
    _jc_ppg_parse_Constant$sub_refs	ppg_parse_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_parse_Constant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_parse_Constant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_parse_Constant$sub_nonrefs	ppg_parse_Constant;
};

// Object instance structure
struct _jc_ppg_parse_Constant$object {
	_jc_ppg_parse_Constant$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_parse_Constant$vtype	*vtype;
	_jc_ppg_parse_Constant$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_parse_Constant$vtype _jc_ppg_parse_Constant$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_parse_Constant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_parse_Constant$class_object;

#endif	/* _JC_ppg_parse_Constant_H_ */
